import 'package:auto_route/auto_route.dart';
import 'package:cs_resources/generated/l10n.dart';
import 'package:cs_resources/theme/app_colors_theme.dart';
import 'package:flutter/material.dart';
import 'package:flutter_hooks/flutter_hooks.dart';
import 'package:hooks_riverpod/hooks_riverpod.dart';
import 'package:widgets/ext/ex_widget.dart';
import 'package:widgets/load_state_layout.dart';
import 'package:widgets/my_text_view.dart';
import 'package:widgets/widget_export.dart';

import '../../detail/form_detail_page.dart';
import 'form_approve_view_model.dart';
import 'item_form_approve.dart';

@RoutePage()
class FormApproveScreen extends HookConsumerWidget {
  @override
  Widget build(BuildContext context, WidgetRef ref) {
    final viewModel = ref.read(formApproveViewModelProvider.notifier);
    final state = ref.watch(formApproveViewModelProvider);

    useEffect(() {
      // 组件挂载时执行 - 执行接口请求
      Future.microtask(() => viewModel.fetchList());
      return () {
        // 组件卸载时执行
      };
    }, []);

    return SizedBox(
      width: double.infinity,
      height: double.infinity,
      child: EasyRefresh(
        controller: viewModel.refreshController,
        onRefresh: viewModel.onRefresh,
        onLoad: viewModel.loadMore,
        child: LoadStateLayout(
          state: state.loadingState,
          errorMessage: state.errorMessage,
          errorRetry: () {
            viewModel.retryRequest();
          },
          successSliverWidget: [
            // 列表
            SliverList(
                delegate: SliverChildBuilderDelegate(
              (context, index) {
                return FormApproveItem(index: index, item: state.datas[index]).onTap(() {
                  //去详情页面
                  FormDetailPage.startInstance(
                    context: context,
                    estateFormId: state.datas[index].estateOnlineFormId ?? "",
                    taskId: state.datas[index].id ?? "",
                    type: state.datas[index].estateOnlineForm?.type?.id ?? "",
                  );
                });
              },
              childCount: state.datas.length,
            )),
          ],
        ),
      ).marginOnly(top: 5, bottom: 5),
    );
  }
}
